==> kakikoMap-1.0.0.tar.gz: kakikoMap/contents_temp/front/conf/require/xxxxxxxx_settingRead.php <==
<?php
/**
* @@DIRECTORY_NAME@@_settingRead.php 処理概要：フロントエンド情報定義
* PHP versions：4.4.2
* @パッケージ：-
* @作者：h.keta
* @作成日/作成者：2006/09/01 (IIS)h.keta
* @更新日/更新者：
* @バージョン：1.0.0
*
*  Copyright (c) 2006 Iwate Information System Co.,Ltd. All Rights Reserved.
*  You may see the License at LICENSE_EN.txt(English) or LICENSE_JA.txt(Japanese).
*/ 

require_once("Config.php");

$dirs = split(PATH_SEPARATOR, ini_get('include_path')); 
foreach ($dirs as $dirpath) {
    $fpath = $dirpath.DIRECTORY_SEPARATOR."kakikomap".DIRECTORY_SEPARATOR."ini".DIRECTORY_SEPARATOR."auto".DIRECTORY_SEPARATOR."@@DIRECTORY_NAME@@_setting.ini";
	if(is_file($fpath)){
		$config = new Config();
		$setting = $config->parseConfig($fpath, "inicommented");
		break;
	}
}

$configsetting = $setting->toArray();

define("LAYERLIST_ROW",         $configsetting['root']['LAYERLIST_ROW']);
define("USERLIST1_ROW",         $configsetting['root']['USERLIST1_ROW']);
define("USERLIST2_ROW",         $configsetting['root']['USERLIST2_ROW']);
define("MEMOTYPELIST_ROW",      $configsetting['root']['MEMOTYPELIST_ROW']);
define("LAYERUSERLIST1_ROW",    $configsetting['root']['LAYERUSERLIST1_ROW']);
define("LAYERUSERLIST2_ROW",    $configsetting['root']['LAYERUSERLIST2_ROW']);
define("LAYERMEMOTYPELIST_ROW", $configsetting['root']['LAYERMEMOTYPELIST_ROW']);
define("MEMOCOMMENTLIST_ROW",   $configsetting['root']['MEMOCOMMENTLIST_ROW']);
define("IMISPACELIST_ROW",      $configsetting['root']['IMISPACELIST_ROW']);

define("VALIDITY_ADD_YEAR",     $configsetting['root']['VALIDITY_ADD_YEAR']);
define("KAKIKO_PASSWORD_NUMBER",$configsetting['root']['PASSWORD_NUMBER']);

define("MOBILE_MAIL_ADDR",		$configsetting['root']['MOBILE_MAIL_ADDR']);
define("POP_SERVER_ADDR",		$configsetting['root']['POP_SERVER_ADDR']);
define("POP_USER",				$configsetting['root']['POP_USER']);
define("POP_PASS",				$configsetting['root']['POP_PASS']);
define("MOBILE_IMG_DIR",		$configsetting['root']['MOBILE_IMG_DIR']);
define("MOBILE_MAX_SIZE",		$configsetting['root']['MOBILE_MAX_SIZE']);
define("TEMP_TYPE",				$configsetting['root']['TEMP_TYPE']);

define("MAP_SERVER_ADDR",		$configsetting['root']['MAP_SERVER_ADDR']);
define("MAP_FILE_NAME",			$configsetting['root']['MAP_FILE_NAME']);
define("KAKIKO_DIR_PATH",		$configsetting['root']['KAKIKO_DIR_PATH']);
define("KAKIKO_LINK_NAME",		$configsetting['root']['KAKIKO_LINK_NAME']);
define("KAKIKO_MOVE_PIXEL",		$configsetting['root']['KAKIKO_MOVE_PIXEL']);

define("MAP_TYPE",              $configsetting['root']['MAP_TYPE']);
define("UPLOAD_MIME_TYPE",      $configsetting['root']['UPLOAD_MIME_TYPE']);
define("MAP_WIDTH",             $configsetting['root']['MAP_WIDTH']);
define("MAP_HEIGHT",            $configsetting['root']['MAP_HEIGHT']);
define("MAP_MOVE",              $configsetting['root']['MAP_MOVE']);
define("MAP_INITPOSITION",      $configsetting['root']['MAP_INITPOSITION']);
define("MAP_AUTOLOGIN",         $configsetting['root']['MAP_AUTOLOGIN']);
define("MAP_PUBLIC",            $configsetting['root']['MAP_PUBLIC']);

define("MAP_CENTER",            $configsetting['root']['MAP_CENTER']);

// レイヤー表示順格納クッキー名
define("LAYERPRIORITY", "@@DIRECTORY_NAME@@_layerpriorityorder")

?>

==> kakikoMap-1.1.0.tar.gz: kakikoMap/contents_temp/front/conf/require/xxxxxxxx_settingRead.php <==
<?php
/**
* @@DIRECTORY_NAME@@_settingRead.php 処理概要：フロントエンド情報定義
* PHP versions：4.4.2
* @パッケージ：-
* @作者：h.keta
* @作成日/作成者：2006/09/01 (IIS)h.keta
* @更新日/更新者：2007/03/01 (IIS)J.Fujikawa
* @バージョン：1.1.0
*
*  Copyright (c) 2006-2007 Iwate Information System Co.,Ltd. All Rights Reserved.
*  You may see the License at LICENSE_EN.txt(English) or LICENSE_JA.txt(Japanese).
*/ 

require_once("Config.php");

$dirs = split(PATH_SEPARATOR, ini_get('include_path')); 
foreach ($dirs as $dirpath) {
    $fpath = $dirpath.DIRECTORY_SEPARATOR."kakikomap".DIRECTORY_SEPARATOR."ini".DIRECTORY_SEPARATOR."auto".DIRECTORY_SEPARATOR."@@DIRECTORY_NAME@@_setting.ini";
	if(is_file($fpath)){
		$config = new Config();
		$setting = $config->parseConfig($fpath, "inicommented");
		break;
	}
}

$configsetting = $setting->toArray();

define("LAYERLIST_ROW",         $configsetting['root']['LAYERLIST_ROW']);
define("USERLIST1_ROW",         $configsetting['root']['USERLIST1_ROW']);
define("USERLIST2_ROW",         $configsetting['root']['USERLIST2_ROW']);
define("MEMOTYPELIST_ROW",      $configsetting['root']['MEMOTYPELIST_ROW']);
define("LAYERUSERLIST1_ROW",    $configsetting['root']['LAYERUSERLIST1_ROW']);
define("LAYERUSERLIST2_ROW",    $configsetting['root']['LAYERUSERLIST2_ROW']);
define("LAYERMEMOTYPELIST_ROW", $configsetting['root']['LAYERMEMOTYPELIST_ROW']);
define("MEMOCOMMENTLIST_ROW",   $configsetting['root']['MEMOCOMMENTLIST_ROW']);
define("IMISPACELIST_ROW",      $configsetting['root']['IMISPACELIST_ROW']);
define("MEMOLIST_ROW_MOBILE",   $configsetting['root']['MEMOLIST_ROW_MOBILE']);

define("VALIDITY_ADD_YEAR",     $configsetting['root']['VALIDITY_ADD_YEAR']);
define("KAKIKO_PASSWORD_NUMBER",$configsetting['root']['PASSWORD_NUMBER']);

define("MOBILE_MAIL_ADDR",		$configsetting['root']['MOBILE_MAIL_ADDR']);
define("POP_SERVER_ADDR",		$configsetting['root']['POP_SERVER_ADDR']);
define("POP_USER",				$configsetting['root']['POP_USER']);
define("POP_PASS",				$configsetting['root']['POP_PASS']);
define("MOBILE_IMG_DIR",		$configsetting['root']['MOBILE_IMG_DIR']);
define("MOBILE_MAX_SIZE",		$configsetting['root']['MOBILE_MAX_SIZE']);
define("TEMP_TYPE",				$configsetting['root']['TEMP_TYPE']);

define("MAP_SERVER_ADDR",		$configsetting['root']['MAP_SERVER_ADDR']);
define("MAP_SERVER_ADDR_LOCAL",		$configsetting['root']['MAP_SERVER_ADDR_LOCAL']);
define("MAP_FILE_NAME",			$configsetting['root']['MAP_FILE_NAME']);
define("KAKIKO_DIR_PATH",		$configsetting['root']['KAKIKO_DIR_PATH']);
define("KAKIKO_LINK_NAME",		$configsetting['root']['KAKIKO_LINK_NAME']);
define("KAKIKO_MOVE_PIXEL",		$configsetting['root']['KAKIKO_MOVE_PIXEL']);

define("MAP_TYPE",              $configsetting['root']['MAP_TYPE']);
define("UPLOAD_MIME_TYPE",      $configsetting['root']['UPLOAD_MIME_TYPE']);
define("MAP_WIDTH",             $configsetting['root']['MAP_WIDTH']);
define("MAP_HEIGHT",            $configsetting['root']['MAP_HEIGHT']);
define("MAP_WIDTH_MOBILE",             $configsetting['root']['MAP_WIDTH_MOBILE']);
define("MAP_HEIGHT_MOBILE",            $configsetting['root']['MAP_HEIGHT_MOBILE']);
define("MAP_MOVE",              $configsetting['root']['MAP_MOVE']);
define("MAP_INITPOSITION",      $configsetting['root']['MAP_INITPOSITION']);
define("MAP_AUTOLOGIN",         $configsetting['root']['MAP_AUTOLOGIN']);
define("MAP_PUBLIC",            $configsetting['root']['MAP_PUBLIC']);

define("MAP_CENTER",            $configsetting['root']['MAP_CENTER']);
define("MAP_CENTER_MOBILE",            $configsetting['root']['MAP_CENTER_MOBILE']);

// レイヤー表示順格納クッキー名
define("LAYERPRIORITY", "@@DIRECTORY_NAME@@_layerpriorityorder")


?>
